@@ -15,7 +15,8 @@ from pytz import reference
 
 from json_schema_for_humans import const
 from json_schema_for_humans.generation_configuration import GenerationConfiguration
-from json_schema_for_humans.schema_node import SchemaNode
+from json_schema_for_humans.const import TemplateName, ResultExtension
+from json_schema_for_humans.schema.schema_node import SchemaNode
 
 SHORT_DESCRIPTION_NUMBER_OF_LINES = 8
 DEFAULT_PATTERN = r"(\[Default - `([^`]+)`\])"
@@ -95,7 +96,11 @@ def get_description(env: Environment, schema_node: SchemaNode) -> str:
         if match:
             description = description[match.span(1)[1] :].lstrip()
 
-    if description and config.description_is_markdown and not config.is_markdown_template:
+    if (
+        description
+        and config.description_is_markdown
+        and not config.template_name.result_extension == ResultExtension.MD
+    ):
         # Markdown templates are expected to already have Markdown descriptions
         md: Markdown = env.globals["jsfh_md"]
         description = Markup(md.convert(description))
